@@ -3,7 +3,7 @@
 #' This is the main function for plotting pedigrees. Many options are available
 #' for controlling the appearance of pedigree symbols and accompanying labels.
 #' The most important ones are illustrated in the Examples section below; for a
-#' complete overview, see the separate page [internalplot], which also explains
+#' complete overview, see the separate page [plotmethods], which also explains
 #' the plotting procedure in more detail.
 #'
 #' The main pedigree layout is calculated with the `kinship2` package, see
@@ -23,14 +23,14 @@
 #'   parameters are not reset after plotting, which may be useful for adding
 #'   additional annotation.
 #' @param ... Arguments passed on to the internal plot functions. For a complete
-#'   list of parameters, see [internalplot]. The most important ones are
+#'   list of parameters, see [plotmethods]. The most important ones are
 #'   illustrated in the Examples below.
 #'
 #' @return A list of three lists with various plot details: `alignment`,
 #'   `annotation`, `scaling`.
 #'
 #' @seealso [plotPedList()], [kinship2::plot.pedigree()]. Plot options are
-#'   documented in [internalplot].
+#'   documented in [plotmethods].
 #'
 #' @examples
 #'
@@ -54,6 +54,9 @@
 #' # Various annotations
 #' plot(x, hatched = "boy", starred = "fa", deceased = "mo", title = "Fam 1")
 #'
+#' # Swap spouse order
+#' plot(x, spouseOrder = c("mo", "fa"))
+#'
 #' #----- ID labels -----
 #'
 #' # Label only some members
@@ -248,7 +251,7 @@ drawPed = function(alignment, annotation = NULL, scaling = NULL, keep.par = FALS
 
 #' Convert pedigree to kinship2 format
 #'
-#' @inheritParams internalplot
+#' @inheritParams plotmethods
 #'
 #' @examples
 #' x = nuclearPed()
@@ -458,10 +461,10 @@ plotPedList = function(plots, widths = NULL, groups = NULL, titles = NULL,
       newpeds = lapply(p, list)
     else { # if list of ped with plot arguments
       p1 = p[[1]]
-      if(inherits(p[[1]], "pedList"))
+      if(inherits(p1, "pedList"))
         class(p[[1]]) = "list"
-      else if (!is.ped(p[[1]]))
-        stop2("First element must be a `ped` object", p[[1]])
+      else if (!is.ped(p1))
+        stop2("First element must be a `ped` object", p1)
       newpeds = list(p)
     }
 
